@@ -6,7 +6,7 @@ set -e
 export LANG='C.UTF-8'
 
 dpkg-checkbuilddeps -d 'python3-apt, apt-btrfs-snapshot, parsewiki, python3-feedparser,
-			python3-mock, xvfb, gir1.2-gtk-3.0, python3-gi, python3-nose, pep8, python3-distutils-extra, python3-update-manager'
+			python3-mock, xvfb, gir1.2-gtk-3.0, python3-gi, python3-nose, pycodestyle, python3-distutils-extra, python3-update-manager'
 
 # make sure the DistUpgrade symlink is good LP: #1824430
 SYMLINK=$(readlink -q DistUpgrade/DistUpgrade)
@@ -24,16 +24,10 @@ xvfb-run nosetests3
 rm -f ./tests/data-sources-list-test/apt.log
 rm -f ./tests/data-sources-list-test/Ubuntu.mirrors
 
-# update demotions
-max_age=$(($(date +%s) - 3600))
-if [ $(stat -c '%Y' utils/demoted.cfg) -lt $max_age ]; then
-    # echo "Running demotions"
-    (cd utils && ./demotions.py disco eoan > demoted.cfg)
-fi
 # when this gets enabled, make sure to add symlink in DistUpgrade
 if [ $(stat -c "%Y" utils/demoted.cfg.bionic) -lt $max_age ]; then
     # echo "Running lts demotions"
-    (cd utils && ./demotions.py bionic eoan > demoted.cfg.bionic)
+    (cd utils && ./demotions.py bionic focal > demoted.cfg.bionic)
 fi
 
 # update apt_btrfs_snapshot.py copy, this needs an installed
